@@ -25,7 +25,7 @@
 G_BEGIN_DECLS
 
 
-extern gboolean userbreak;
+extern gboolean abort_break;
 
 
 /******************************************************************************
@@ -33,10 +33,19 @@ extern gboolean userbreak;
 * ja:中断ダイアログ関数群                                                     *
 *                                                                             *
 ******************************************************************************/
-/*  ja:中断ダイアログ表示
-    text,説明文                                                             */
+/*  ja:中断ボタン取得 */
 GtkWidget *
-abort_dialog (const gchar *text);
+abort_box_get_widget (void);
+
+
+/*  ja:中断ボタン開始 */
+void
+abort_box_start (void);
+
+
+/*  ja:中断ボタン終了 */
+void
+abort_box_end (void);
 
 
 G_END_DECLS
