@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "abort.h"
 #include "command.h"
@@ -1010,22 +1009,20 @@ void
 command_next (GtkWidget *widget,
               gpointer   user_data)
 {
-  GtkWidget *dialog;
   TmaidWindow *tmaid;
 
   tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
-  /* en:Dialog Box */
-  /* ja:ダイアログボックス */
-  userbreak = TRUE;
-  dialog = abort_dialog (_("Finding"));
-  gtk_grab_add (dialog);
+  /* ja:中断ボタン */
+  abort_box_start ();
   find_operation (tmaid, &tmaid->cursor, &tmaid->select, find_text[0],
                         GPOINTER_TO_INT (user_data) ? find_arrow : !find_arrow,
                                                             find_ignorecase);
-  gtk_grab_remove (dialog);
-  gtk_widget_destroy (dialog);
-  if (userbreak && tmaid->select.x < 0)
+  /* ja:中断ボタン */
+  abort_box_end ();
+  if (abort_break && tmaid->select.x < 0)
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
@@ -1063,7 +1060,6 @@ command_replace (GtkWidget *widget,
       gchar *text;
       gint i, count = 0;
       GdkPoint select;
-      GtkWidget *dialog = NULL;
       ReplaceInfo ri;
 
       set_menu_bar (tmaid);
@@ -1121,19 +1117,13 @@ command_replace (GtkWidget *widget,
       select = tmaid->select;
       ri.arrow = replace_arrow;
       ri.ignorecase = replace_ignorecase;
-      userbreak = TRUE;
+      /* ja:中断ボタン */
+      abort_box_start ();
       do
         {
           gint bytes, data_pos;
           TmaidHistory *d;
 
-          /* en:Dialog Box */
-          /* ja:ダイアログボックス */
-          if (!dialog)
-            {
-              dialog = abort_dialog (_("Replacing"));
-              gtk_grab_add (dialog);
-            }
           find_operation (tmaid, &tmaid->cursor, &select, find_text[0],
                                             replace_arrow, replace_ignorecase);
           if (tmaid->select.x < 0)
@@ -1142,14 +1132,6 @@ command_replace (GtkWidget *widget,
           bytes = edit_get_sel_bytes (tmaid, &tmaid->select, &tmaid->cursor);
           if (result != REPLACE_ALL)
             {
-              /* en:Dialog Box */
-              /* ja:ダイアログボックス */
-              if (dialog)
-                {
-                  gtk_grab_remove (dialog);
-                  gtk_widget_destroy (dialog);
-                  dialog = NULL;
-                }
               ri.src = g_malloc (bytes + 1);
               edit_cpy_sel_mem (tmaid, &tmaid->select, &tmaid->cursor, ri.src);
               ri.src[bytes] = '\0';
@@ -1178,15 +1160,12 @@ command_replace (GtkWidget *widget,
           orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
         }
       while (result != REPLACE_CANCEL);
-      /* en:Dialog Box */
-      /* ja:ダイアログボックス */
-      if (dialog)
-        {
-          gtk_grab_remove (dialog);
-          gtk_widget_destroy (dialog);
-        }
+      /* ja:中断ボタン */
+      abort_box_end ();
       if (!replace)
         {
+          GtkWidget *dialog;
+
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
@@ -1198,6 +1177,8 @@ command_replace (GtkWidget *widget,
         }
       else if (result == REPLACE_ALL)
         {
+          GtkWidget *dialog;
+
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
