@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "abort.h"
 #include "charset.h"
@@ -50,7 +49,6 @@ file_open_text (const gchar *file,
   FileIO *fio;
   LineBuffer *p;
   GError *error = NULL;
-  GtkWidget *dialog;
 
   charset = g_strsplit (tmaid->ft.charset, ",", 0);
   g_free (tmaid->ft.charset);
@@ -58,16 +56,14 @@ file_open_text (const gchar *file,
   tmaid->max = 1;
   tmaid->off = 0;
   tmaid->start = p;
-  /* ja:ダイアログボックス */
-  userbreak = TRUE;
-  dialog = abort_dialog (_("Reading"));
-  gtk_grab_add (dialog);
+  /* ja:中断ボタン */
+  abort_box_start ();
   /* ja:読み込み */
   fio = fileio_open (file, FILEIO_ACCESS_READ, FILEIO_SHARE_READ,
                                                     FILEIO_MODE_OPEN_EXISTING);
   if (fio)
     {
-      while (userbreak && (leng = fileio_read (fio, buf, 16384)) > 0)
+      while (abort_break && (leng = fileio_read (fio, buf, 16384)) > 0)
         {
           while (gtk_events_pending ())
             gtk_main_iteration ();
@@ -80,8 +76,8 @@ file_open_text (const gchar *file,
   if (!inbuf)
     {
       /* ja:終了処理 */
-      gtk_grab_remove (dialog);
-      gtk_widget_destroy (dialog);
+      /* ja:中断ボタン */
+      abort_box_end ();
 #ifdef G_OS_WIN32
       tmaid->ft.crlf = 0;
 #else /* not G_OS_WIN32 */
@@ -92,7 +88,7 @@ file_open_text (const gchar *file,
       return;
     }
   /* ja:キャラクターセット変換 */
-  for (i = 0; userbreak && charset[i]; i++)
+  for (i = 0; abort_break && charset[i]; i++)
     {
       while (gtk_events_pending ())
         gtk_main_iteration ();
@@ -128,7 +124,7 @@ file_open_text (const gchar *file,
     }
   /* ja:キャラクターセット変換を強行する */
   if (!outbuf)
-    for (i = 0; userbreak && !outbuf && charset[i]; i++)
+    for (i = 0; abort_break && !outbuf && charset[i]; i++)
       {
         gchar *buffer;
         gssize bytes_read_prev = -1;
@@ -158,7 +154,7 @@ file_open_text (const gchar *file,
 
       outbuf = inbuf;
       leng = length;
-      while (userbreak && leng > 0
+      while (abort_break && leng > 0
                     && !g_utf8_validate (inbuf, leng, (const gchar **)&ptr))
         {
           while (gtk_events_pending ())
@@ -183,7 +179,7 @@ file_open_text (const gchar *file,
 
       crlf[0] = crlf[1] = crlf[2] = 0;
       i = 0;
-      while (userbreak && i < length)
+      while (abort_break && i < length)
         if (i <= length - 2 && outbuf[i] == '\r' && outbuf[i + 1] == '\n')
           {
             i += 2;
@@ -214,7 +210,7 @@ file_open_text (const gchar *file,
 #endif /* not G_OS_WIN32 */
     }
   /* ja:ラインバッファに変換する */
-  for (i = 0; userbreak && i < length; i = j)
+  for (i = 0; abort_break && i < length; i = j)
     {
       while (gtk_events_pending ())
         gtk_main_iteration ();
@@ -324,9 +320,8 @@ file_open_text (const gchar *file,
                 }
             }
       }
-  /* ja:終了処理 */
-  gtk_grab_remove (dialog);
-  gtk_widget_destroy (dialog);
+  /* ja:中断ボタン */
+  abort_box_end ();
 }
 
 
@@ -540,7 +535,6 @@ file_save_text (const gchar *file,
   FileIO *fio;
   LineBuffer *p;
   GError *error = NULL;
-  GtkWidget *dialog;
 
   p = tmaid->start;
   while (p->prev)
@@ -551,12 +545,10 @@ file_save_text (const gchar *file,
       case  1: crlf[0] = '\r'; crlf_leng = 1; break;
       default: crlf[0] = '\n'; crlf_leng = 1;
     }
-  /* ja:ダイアログボックス */
-  userbreak = TRUE;
-  dialog = abort_dialog (_("Writing"));
-  gtk_grab_add (dialog);
+  /* ja:中断ボタン */
+  abort_box_start ();
   /* ja:書く */
-  while (userbreak && p)
+  while (abort_break && p)
     {
       gsize leng;
 
@@ -578,7 +570,7 @@ file_save_text (const gchar *file,
           leng = p->length;
         }
       ptr = p->text;
-      while (userbreak && leng > 0)
+      while (abort_break && leng > 0)
         {
           gchar *outbuf;
           gsize bytes_read, bytes_written;
@@ -611,10 +603,12 @@ file_save_text (const gchar *file,
                                                 G_CONVERT_ERROR_PARTIAL_INPUT))
             {
               /* ja:キャラクターセットが無効 */
+              GtkWidget *dialog;
+
               g_clear_error (&error);
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
               g_free (buf);
+              /* ja:中断ボタン */
+              abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -645,18 +639,22 @@ file_save_text (const gchar *file,
                             ? "\\u%04X" : "\\u%04x", g_utf8_get_char (ptr));
                     break;
                   default:
-                    gtk_grab_remove (dialog);
-                    gtk_widget_destroy (dialog);
-                    g_free (buf);
-                    dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                    {
+                      GtkWidget *dialog;
+
+                      g_free (buf);
+                      /* ja:中断ボタン */
+                      abort_box_end ();
+                      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Invalid byte sequence in conversion input"));
-                    g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                      g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
-                    gtk_dialog_run (GTK_DIALOG (dialog));
-                    gtk_widget_destroy (dialog);
-                    return FALSE;
+                      gtk_dialog_run (GTK_DIALOG (dialog));
+                      gtk_widget_destroy (dialog);
+                      return FALSE;
+                    }
                 }
               bytes_written = g_strlen (outbuf);
               buf = realloc (buf, length + bytes_written);
@@ -670,16 +668,18 @@ file_save_text (const gchar *file,
       p = p->next;
     }
   g_clear_error (&error);
-  if (userbreak)
+  if (abort_break)
     {
       /* ja:開く */
       fio = fileio_open (file, FILEIO_ACCESS_WRITE, FILEIO_SHARE_READ,
                                                     FILEIO_MODE_CREATE_ALWAYS);
       if (!fio)
         {
-          gtk_grab_remove (dialog);
-          gtk_widget_destroy (dialog);
+          GtkWidget *dialog;
+
           g_free (buf);
+          /* ja:中断ボタン */
+          abort_box_end ();
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -691,7 +691,7 @@ file_save_text (const gchar *file,
           return FALSE;
         }
       ptr = buf;
-      while (userbreak && length > 0)
+      while (abort_break && length > 0)
         {
           gssize leng;
 
@@ -700,10 +700,12 @@ file_save_text (const gchar *file,
           leng = MIN (length, 16384);
           if (fileio_write (fio, ptr, leng) != leng)
             {
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
+              GtkWidget *dialog;
+
               fileio_close (fio);
               g_free (buf);
+              /* ja:中断ボタン */
+              abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -719,9 +721,11 @@ file_save_text (const gchar *file,
         }
       if (!fileio_close (fio))
         {
-          gtk_grab_remove (dialog);
-          gtk_widget_destroy (dialog);
+          GtkWidget *dialog;
+
           g_free (buf);
+          /* ja:中断ボタン */
+          abort_box_end ();
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -734,8 +738,7 @@ file_save_text (const gchar *file,
         }
     }
   g_free (buf);
-  /* ja:終了処理 */
-  gtk_grab_remove (dialog);
-  gtk_widget_destroy (dialog);
-  return userbreak;
+  /* ja:中断ボタン */
+  abort_box_end ();
+  return abort_break;
 }
