@@ -173,7 +173,7 @@ find_operation (TmaidWindow    *tmaid,
                   /* ja:改行 */
                   while (gtk_events_pending ())
                     gtk_main_iteration ();
-                  if (!userbreak)
+                  if (!abort_break)
                     goto loop;
                   if (!q->margin)
                     {
@@ -262,7 +262,7 @@ find_operation (TmaidWindow    *tmaid,
                   /* ja:改行 */
                   while (gtk_events_pending ())
                     gtk_main_iteration ();
-                  if (!userbreak)
+                  if (!abort_break)
                     goto loop;
                   q = q->prev;
                   type = g_realloc (type, q->length * sizeof (gint));
