@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "abort.h"
@@ -42,7 +41,7 @@ BOOL CALLBACK
 PrintProc (HDC hdc,
            int nError)
 {
-  return userbreak;
+  return abort_break;
 }
 #endif /* G_OS_WIN32 */
 
@@ -61,8 +60,7 @@ print_out (TmaidWindow *tmaid,
   GdkGC *gc;
   GdkPixmap *pixmap;
   GdkPixbuf *pixbuf;
-  GdkPoint start,end;
-  GtkWidget *dialog;
+  GdkPoint start, end;
 #ifdef G_OS_WIN32
   gchar *name, *utf8str;
   HBITMAP hBitmap;
@@ -102,6 +100,8 @@ print_out (TmaidWindow *tmaid,
   hDC = CreateCompatibleDC (prncfg->pd.hDC);
   if (!hDC)
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -115,6 +115,8 @@ print_out (TmaidWindow *tmaid,
     }
   if (SetAbortProc (prncfg->pd.hDC, PrintProc) <= 0)
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -146,6 +148,8 @@ print_out (TmaidWindow *tmaid,
   di.lpszDocName = name ? name : "Text maid";
   if (StartDoc (prncfg->pd.hDC, &di) <= 0)
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -167,6 +171,8 @@ print_out (TmaidWindow *tmaid,
       fp = popen (prncfg->printer, "w");
       if (!fp)
         {
+          GtkWidget *dialog;
+
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -185,6 +191,8 @@ print_out (TmaidWindow *tmaid,
       fp = fopen (prncfg->file, "wt");
       if (!fp)
         {
+          GtkWidget *dialog;
+
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -205,10 +213,8 @@ print_out (TmaidWindow *tmaid,
   gc = gdk_gc_new (pixmap);
   gdk_gc_set_line_attributes (gc, 1,
                                 GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
-  /* ja:ダイアログボックス */
-  userbreak = TRUE;
-  dialog = abort_dialog (_("Printing"));
-  gtk_grab_add (dialog);
+  /* ja:中断ボタン */
+  abort_box_start ();
 #if defined (G_OS_UNIX)
   for (i = 0; i < prncfg->mode ? prncfg->copies : 1; i++)
 #elif defined (G_OS_WIN32)
@@ -288,9 +294,11 @@ print_out (TmaidWindow *tmaid,
           hBitmap = SelectObject (hDC, (HBITMAP)GDK_WINDOW_HWND (pixmap));
           if (StartPage (prncfg->pd.hDC) <= 0)
             {
+              GtkWidget *dialog;
+
               hBitmap = SelectObject (hDC, hBitmap);
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
+              /* ja:中断ボタン */
+              abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -304,9 +312,11 @@ print_out (TmaidWindow *tmaid,
           if (!StretchBlt (prncfg->pd.hDC, 0, 0, prncfg->width, prncfg->height,
                                                 hDC, 0, 0, sx, sy, SRCCOPY))
             {
+              GtkWidget *dialog;
+
               EndPage (prncfg->pd.hDC);
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
+              /* ja:中断ボタン */
+              abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -320,9 +330,11 @@ print_out (TmaidWindow *tmaid,
             }
           if (EndPage (prncfg->pd.hDC) <= 0)
             {
+              GtkWidget *dialog;
+
               hBitmap = SelectObject (hDC, hBitmap);
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
+              /* ja:中断ボタン */
+              abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -385,16 +397,16 @@ print_out (TmaidWindow *tmaid,
             }
           fputs ("grestore\nshowpage\n", fp);
 #endif /* not G_OS_WIN32 */
-          if (!userbreak)
+          if (!abort_break)
             {
-              gtk_grab_remove (dialog);
-              gtk_widget_destroy (dialog);
+              /* ja:中断ボタン */
+              abort_box_end ();
               goto loop;
             }
         }
     }
-  gtk_grab_remove (dialog);
-  gtk_widget_destroy (dialog);
+  /* ja:中断ボタン */
+  abort_box_end ();
   loop:
   /* ja:終了処理 */
   g_object_unref (gc);
@@ -403,6 +415,8 @@ print_out (TmaidWindow *tmaid,
 #ifdef G_OS_WIN32
   if (EndDoc (prncfg->pd.hDC) <= 0)
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -417,6 +431,8 @@ print_out (TmaidWindow *tmaid,
     }
   if (!DeleteDC (prncfg->pd.hDC))
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
@@ -430,6 +446,8 @@ print_out (TmaidWindow *tmaid,
     }
   if (!DeleteDC (hDC))
     {
+      GtkWidget *dialog;
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
