@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "charset.h"
 #include "edit.h"
@@ -393,10 +392,9 @@ signal_expose (GtkWidget      *widget,
                GdkEventExpose *event,
                TmaidWindow    *tmaid)
 {
-  gboolean select, space = FALSE;
-  gint i, x, y, data_pos, length, width;
+  gint y;
   GdkGC *gc;
-  GdkPoint start, end, cursor, pt[4];
+  GdkPoint start, end, cursor;
   LineBuffer *p;
 
   gc = gdk_gc_new (widget->window);
@@ -433,6 +431,8 @@ signal_expose (GtkWidget      *widget,
   if (tmaid->ft.gline)
     {
       /* ja:グリッド */
+      gint x;
+
       gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 7);
       for (x = tmaid->font_width - 1; x < widget->allocation.width;
@@ -447,6 +447,8 @@ signal_expose (GtkWidget      *widget,
   if (tmaid->ft.vline)
     {
       /* ja:縦線 */
+      gint x;
+
       gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 7);
       for (x = (tmaid->ft.tab - tmaid->top.x % tmaid->ft.tab)
@@ -459,6 +461,8 @@ signal_expose (GtkWidget      *widget,
   if (tmaid->ft.mline)
     {
       /* ja:右マージン */
+      gint x;
+
       gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                         ? system_color : tmaid->ft.color) + 6);
       x = (tmaid->ft.margin - tmaid->top.x) * tmaid->font_width;
@@ -470,12 +474,16 @@ signal_expose (GtkWidget      *widget,
                                 y < event->area.y + event->area.height && p;
                                         y += tmaid->font_height, p = p->next)
     {
+      gint x, data_pos = 0;
+
       if (y + tmaid->font_height < event->area.y)
         continue;
-      x = -tmaid->top.x * tmaid->font_width;
-      data_pos = 0;
+      x = - tmaid->top.x * tmaid->font_width;
       while (x <= event->area.x + event->area.width && data_pos < p->length)
         {
+          gboolean select;
+          gint width;
+
           if (x + MAX (tmaid->ft.tab, 2) * tmaid->font_width < event->area.x)
             {
               /* ja:左側の表示されない部分を計算する */
@@ -486,7 +494,7 @@ signal_expose (GtkWidget      *widget,
                         * tmaid->ft.tab - tmaid->top.x) * tmaid->font_width;
                   data_pos++;
                 }
-              else if (data_pos + charset_length(p->text[data_pos])
+              else if (data_pos + charset_length (p->text[data_pos])
                                                                 <= p->length)
                 {
                   /* ja:半角/全角 */
@@ -550,6 +558,8 @@ signal_expose (GtkWidget      *widget,
             }
           else if (data_pos + charset_length (p->text[data_pos]) <= p->length)
             {
+              gboolean space = FALSE;
+
               /* ja:半角/全角 */
               width = tmaid->font_width * charset_width (tmaid->layout,
                                         p->text + data_pos,
@@ -571,7 +581,9 @@ signal_expose (GtkWidget      *widget,
                 }
               if (tmaid->ft.space)
                 {
-                  space = FALSE;/* ja:全角スペース判定 */
+                  /* ja:全角スペース判定 */
+                  gint i;
+
                   for (i = 0; charset_space[i] != 0; i += charset_space[i] + 1)
                     if (charset_length (p->text[data_pos]) == charset_space[i]
                             && g_memcmp (p->text + data_pos,
@@ -589,15 +601,21 @@ signal_expose (GtkWidget      *widget,
               else
                 {
                   /* ja:文字 */
+                  int w;
+
                   pango_layout_set_text (tmaid->layout, p->text + data_pos,
                                         charset_length (p->text[data_pos]));
-                  gdk_draw_layout (widget->window, gc, x, y, tmaid->layout);
+                  pango_layout_get_pixel_size (tmaid->layout, &w, NULL);
+                  gdk_draw_layout (widget->window, gc, x + (width - w) / 2, y,
+                                                                tmaid->layout);
                 }
               data_pos += charset_length (p->text[data_pos]);
             }
           else
             {
               /* ja:強制半角 */
+              int w;
+
               width = tmaid->font_width;
               if (select)
                 {
@@ -615,7 +633,9 @@ signal_expose (GtkWidget      *widget,
                                         ? system_color : tmaid->ft.color);
                 }
               pango_layout_set_text (tmaid->layout, p->text + data_pos, 1);
-              gdk_draw_layout (widget->window, gc, x, y, tmaid->layout);
+              pango_layout_get_pixel_size (tmaid->layout, &w, NULL);
+              gdk_draw_layout (widget->window, gc, x + (width - w) / 2, y,
+                                                                tmaid->layout);
               data_pos++;
             }
           /* ja:キャレットの描画 */
@@ -652,6 +672,9 @@ signal_expose (GtkWidget      *widget,
             }
           else
             {
+              gint length;
+              GdkPoint pt[4];
+
               if (p->margin)
                 {
                   /* ja:右マージンによる改行 */
@@ -686,8 +709,8 @@ signal_expose (GtkWidget      *widget,
         }
     }
 
-    g_object_unref (gc);
-    return TRUE;
+  g_object_unref (gc);
+  return TRUE;
 }
 
 
