@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,14 +13,14 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "tmaid.h"
 #include <locale.h>
 #ifdef G_OS_WIN32
 # include <windows.h>
 #endif /* G_OS_WIN32 */
+#include "abort.h"
 #include "command.h"
 #include "file.h"
 #include "find.h"
@@ -69,6 +69,7 @@ GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *mdi;                     /* en:MDI */
 GtkWidget *status;                  /* ja:ステータスウインドウ */
 GtkWidget *label_cursor;            /* ja:カーソル座標 */
+GtkWidget *main_box;                /* ja:メインボックス */
 PangoFontDescription *system_font = NULL;
 GdkColor system_color[12] = {
     {0, 0x0000, 0x0000, 0x0000}, {0, 0xffff, 0xffff, 0xffff},
@@ -559,6 +560,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "Text maid");
   gtk_window_set_default_size (GTK_WINDOW (window), def_width, def_height);
+  gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
   glist = g_list_append (NULL, gdk_pixbuf_new_from_xpm_data (tmaid16_xpm));
   glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (tmaid24_xpm));
   glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (tmaid32_xpm));
@@ -616,11 +618,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
   misc_create_menu (menu_entries, accel_group);
   /* ja:ファイルの履歴 */
   for (i = 0; menu_entries[i].path; i++)
-#if GLIB_CHECK_VERSION(2,2,0)
     if (g_str_has_prefix (menu_entries[i].path, "/file/"))
-#else /* not GLIB_CHECK_VERSION(2,2,0) */
-    if (g_strncmp (menu_entries[i].path, "/file/", 6) == 0)
-#endif /* not GLIB_CHECK_VERSION(2,2,0) */
       count++;
   orz_history_set_menu (ORZ_HISTORY (history),
                         misc_find_menu (menu_entries, "/file/"), count - 3);
@@ -635,8 +633,19 @@ TMAID_COPYRIGHT_NOTICE"\n"
   accel = orz_accel_new ();
   orz_accel_set_window (ORZ_ACCEL (accel), GTK_WINDOW (window));
   orz_accel_add_accel_group (ORZ_ACCEL (accel), accel_group);
-  /* ja:テーブル */
-  table = gtk_table_new (1, 5, FALSE);
+  /* ja:メインボックス */
+  main_box = gtk_vbox_new (FALSE, 0);
+  handle = gtk_handle_box_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_find_menu (menu_entries, "/"));
+  gtk_box_pack_start (GTK_BOX (main_box), handle, FALSE, FALSE, 0);
+  handle = gtk_handle_box_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
+  gtk_container_add (GTK_CONTAINER (handle),
+                                        misc_create_toolbar (toolbar_entries));
+  gtk_box_pack_start (GTK_BOX (main_box), handle, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (main_box), mdi, TRUE, TRUE, 0);
   /* ja:ステータスバー */
   status = gtk_statusbar_new ();
   /* ja:カーソル座標 */
@@ -644,28 +653,21 @@ TMAID_COPYRIGHT_NOTICE"\n"
   gtk_label_set_justify (GTK_LABEL (label_cursor), GTK_JUSTIFY_CENTER);
   frame = gtk_frame_new (NULL);
   gtk_container_add( GTK_CONTAINER (frame), label_cursor);
-  /* ja:テキスト */
-  label = gtk_label_new ("");
-  g_signal_connect (G_OBJECT (label), "style-set",
-                                        G_CALLBACK (signal_style_set), NULL);
-  /* ja:垂直ボックス/ハンドルボックス */
-  vbox = gtk_vbox_new (FALSE, 0);
-  handle = gtk_handle_box_new ();
-  gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle),
-                                        misc_find_menu (menu_entries, "/"));
-  gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
-  handle = gtk_handle_box_new ();
-  gtk_container_set_border_width (GTK_CONTAINER (handle), 2);
-  gtk_container_add (GTK_CONTAINER (handle),
-                                        misc_create_toolbar (toolbar_entries));
-  gtk_box_pack_start (GTK_BOX (vbox), handle, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), mdi, TRUE, TRUE, 0);
+  /* ja:テーブル */
+  table = gtk_table_new (1, 5, FALSE);
   gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
             GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_table_attach (GTK_TABLE (table), status, 1, 5, 0, 1,
             GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+  /* ja:テキスト */
+  label = gtk_label_new ("");
+  g_signal_connect (G_OBJECT (label), "style-set",
+                                        G_CALLBACK (signal_style_set), NULL);
+  /* ja:垂直ボックス */
+  vbox = gtk_vbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), main_box, TRUE, TRUE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), table, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox), abort_box_get_widget (), FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
   /* ja:タイマ */
@@ -691,7 +693,8 @@ TMAID_COPYRIGHT_NOTICE"\n"
 
   /* ja:表示 */
   gtk_widget_show_all (window);
-  gtk_widget_hide_all (label);
+  gtk_widget_hide (abort_box_get_widget ());
+  gtk_widget_hide (label);
 
   /* ja:システム色 */
   style = gtk_widget_get_style (label);
